@@ -12,12 +12,7 @@ class IApplication(interface.Interface):
 
     plugins = interface.Attribute("A list of found PlugBoard plugins")
 
-    def __init__(self):
-        """
-        Create an application and give the path where to search for plugin entries
-        """
-
-    def register(self, ofrom, oto, name=''):
+    def register(ofrom, oto, name=''):
         """
         Register adaption from ofrom object to oto object gaining automatically their interfaces
         """
@@ -44,9 +39,9 @@ class Application(object):
         except:
             pass
         if callable(obj):
-            return interface.implementedBy(obj)
+            return iter(interface.implementedBy(obj)).next()
         else:
-            return interface.providedBy(obj)
+            return iter(interface.providedBy(obj)).next()
             
     def register(self, ofrom, oto, name=''):
         self.registry.register([self._get_interface(ofrom)], self._get_interface(oto), name, oto)
